import modeltools.hycom
import abfile
import numpy
import matplotlib.pyplot as plt
from matplotlib.colors import BoundaryNorm
from matplotlib.ticker import MaxNLocator
from matplotlib.ticker import MultipleLocator, FormatStrFormatter
from matplotlib import ticker
from mpl_toolkits.basemap import Basemap
import pickle
import scipy.io as sio
import numpy as np
import numpy.ma as ma
from subroutine_postprocess import monthindex
import calendar
from netCDF4 import Dataset as NetCDFFile
import os,fnmatch
import warnings
import datetime
from scipy import stats
from prettytable import PrettyTable

def filter_nan(s,o):
    """
    this functions removed the data  from simulated and observed data
    whereever the observed data contains nan
    
    this is used by all other functions, otherwise they will produce nan as 
    output
    """
    if np.sum(~np.isnan(s*o))>=1:
        data = np.array([s.flatten(),o.flatten()])
        data = np.transpose(data)
        data = data[~np.isnan(data).any(1)]
        s = data[:,0]
        o = data[:,1]
    return s, o

def pc_bias(s,o):
    s,o = filter_nan(s,o)
    return 100.0*sum(s-o)/sum(o)

def bias(s,o):
    s,o = filter_nan(s,o)
    return np.mean(s-o)

def correlation(s,o):
    s,o = filter_nan(s,o)
    if s.size == 0:
        corr = np.NaN
    else:
        corr = np.corrcoef(o, s)[0,1]

    return corr

def rmse(s,o):
    s,o = filter_nan(s,o)
    return np.sqrt(np.mean((s-o)**2))

def nstd(s,o):
    # norm. std. dev.
    s,o = filter_nan(s,o)
    return np.std(s)/np.std(o)

def me(s,o):
    s,o = filter_nan(s,o)
    return 1. - ( np.sum((o-s)**2) / np.sum((o-np.mean(o))**2) )

year       = '1991_2010'
pathsuffix1= './' #EXP2
pathsuffix2= './' #EXP1
pathsuffix3= './' #EXP3

gfile=abfile.ABFileGrid("../model_setup/topo/regional.grid",'r')
plon=gfile.read_field("plon")
plat=gfile.read_field("plat")
m = Basemap(width=8500000,height=8500000,
resolution='c',projection='stere',\
lat_ts=80,lat_0=80,lon_0=-40.,round='True')
x,y=m(numpy.rot90(plon),numpy.rot90(plat))
gfile.close()

bfile=abfile.ABFileBathy("../model_setup/topo/depth_NATa1.00_01.a","r",idm=gfile.idm,jdm=gfile.jdm)
depthm=bfile.read_field("depth")

filename = '%sEXP1_%s.pckl' %( pathsuffix1,str(year) )
f = open(filename,'rb')
Colocated1,Interpolated1,ALGAE1,CHLSAT1 = pickle.load(f)
f.close()
filename = '%EXP2_%s.pckl' %( pathsuffix2,str(year) )
f = open(filename,'rb')
Colocated2,Interpolated2,ALGAE2,CHLSAT2 = pickle.load(f)
f.close()
filename = '%sEXP3_%s.pckl' %( pathsuffix3,str(year) )
f = open(filename,'rb')
Colocated3,Interpolated3,ALGAE3,CHLSAT3 = pickle.load(f)
f.close()


### ALGAE ########################################## 
cmin = 0.; cmax = 225.
var=ALGAE2["PP"]["annual"] * 365. / 1000.
title = 'Annual Primary Productivity'# (mgC m-2 d-1) 
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r') 
figure=plt.figure(figsize=(12,7))
ax=figure.add_subplot(311)
ax.set_position([0.05,0.507,0.25,0.45])

levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(x,y,numpy.rot90(var),cmap=cmap,norm=norm)
plt.title(title,FontSize=17)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
plt.text(0.015,0.85, 'a)',transform=ax.transAxes,FontSize=20)
cbaxes = figure.add_axes([0.3, 0.5257, 0.015, 0.175])
cb = ax.figure.colorbar(pmesh, cax = cbaxes)

cmin = 0.; cmax = 3.
var=ALGAE2["DIA"]["annual"]/1000.
title = 'Diatoms'# (gC m-2)   
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r') 
ax=figure.add_subplot(312)
ax.set_position([0.375,0.507,0.25,0.45])

levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(x,y,numpy.rot90(var),cmap=cmap,norm=norm)
plt.title(title,Fontsize=17)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
plt.text(0.015,0.85, 'c)',transform=ax.transAxes,FontSize=20)
#cbaxes = figure.add_axes([0.89, 0.1, 0.035, 0.5])
#cb = ax.figure.colorbar(pmesh, cax = cbaxes)

cmin = 0.; cmax = 3.
var=ALGAE2["FLA"]["annual"]/1000.
title = 'Flagellates'# (gC m-2)                          
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r') 
ax=figure.add_subplot(313)
ax.set_position([0.685,0.507,0.25,0.45])

levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(x,y,numpy.rot90(var),cmap=cmap,norm=norm)
plt.title(title,FontSize=17)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
plt.text(0.015,0.85, 'e)',transform=ax.transAxes,FontSize=20)
#cbaxes = figure.add_axes([0.89, 0.1, 0.035, 0.5])
#cb = ax.figure.colorbar(pmesh, cax = cbaxes)

cmin = 0.; cmax = 3.
var=ALGAE2["MIC"]["annual"]/1000.
title = 'Microzooplankton'# (gC m-2)                          
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r')
ax=figure.add_subplot(322)
ax.set_position([0.375,0.007,0.25,0.45])

levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(x,y,numpy.rot90(var),cmap=cmap,norm=norm)
plt.title(title,FontSize=17)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
plt.text(0.015,0.85, 'd)',transform=ax.transAxes,FontSize=20)
#cbaxes = figure.add_axes([0.89, 0.1, 0.035, 0.5])
#cb = ax.figure.colorbar(pmesh, cax = cbaxes)

cmin = 0.; cmax = 3.
var=ALGAE2["MES"]["annual"]/1000.
title = 'Mesozooplankton'# (gC m-2)                          
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r')
ax=figure.add_subplot(323)
ax.set_position([0.685,0.007,0.25,0.45])

levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(x,y,numpy.rot90(var),cmap=cmap,norm=norm)
plt.title(title,FontSize=17)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
plt.text(0.015,0.85, 'f)',transform=ax.transAxes,FontSize=20)
cbaxes = figure.add_axes([0.935, 0.0257, 0.015, 0.175])
cb = ax.figure.colorbar(pmesh, cax = cbaxes)

cmin = 0.; cmax = 1.5
var=ALGAE2["CHL"]["annual"]
title = 'Chlorophyll a'# (gC m-2)                          
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r')
ax=figure.add_subplot(321)
ax.set_position([0.05,0.007,0.25,0.45])

levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(x,y,numpy.rot90(var),cmap=cmap,norm=norm)
plt.title(title,FontSize=17)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
plt.text(0.015,0.85, 'b)',transform=ax.transAxes,FontSize=20)
cbaxes = figure.add_axes([0.3, 0.0257, 0.015, 0.175])
cb = ax.figure.colorbar(pmesh, cax = cbaxes)

figure.canvas.print_figure('./plots/algae.png')
plt.close(figure)
########################################################################

### NUTRIENTS ###################################### 
cmin = 0.; cmax = 15.
var=Interpolated2['NO3']["annual"][0,:,:]
var = numpy.ma.masked_where(depthm<5.,var)
title = 'Nitrate (5m)' 
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r')
figure=plt.figure(figsize=(12,7))
ax=figure.add_subplot(311)
ax.set_position([0.05,0.507,0.25,0.45])

levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(x,y,numpy.rot90(var),cmap=cmap,norm=norm)
plt.title(title,FontSize=17)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
plt.text(0.015,0.85, 'a)',transform=ax.transAxes,FontSize=20)

cmin = 0.; cmax = 1.5
var=Interpolated2['PHO']["annual"][0,:,:]
var = numpy.ma.masked_where(depthm<5.,var)
title = 'Phosphate (5m)'   
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r')
ax=figure.add_subplot(312)
ax.set_position([0.365,0.507,0.25,0.45])

levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(x,y,numpy.rot90(var),cmap=cmap,norm=norm)
plt.title(title,Fontsize=17)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
plt.text(0.015,0.85, 'b)',transform=ax.transAxes,FontSize=20)

cmin = 0.; cmax = 30.
var=Interpolated2['SIL']["annual"][0,:,:]
var = numpy.ma.masked_where(depthm<5.,var)
title = 'Silicate (5m)'                         
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r')
ax=figure.add_subplot(313)
ax.set_position([0.685,0.507,0.25,0.45])

levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(x,y,numpy.rot90(var),cmap=cmap,norm=norm)
plt.title(title,FontSize=17)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
plt.text(0.015,0.85, 'c)',transform=ax.transAxes,FontSize=20)
#cbaxes = figure.add_axes([0.935, 0.5257, 0.015, 0.175])
#cb = ax.figure.colorbar(pmesh, cax = cbaxes)

cmin = 0.; cmax = 15.
var=Interpolated2['NO3']["annual"][3,:,:]
var = numpy.ma.masked_where(depthm<100.,var)
title = 'Nitrate (100m)'      
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r')
ax=figure.add_subplot(321)
ax.set_position([0.05,0.007,0.25,0.45])

levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(x,y,numpy.rot90(var),cmap=cmap,norm=norm)
plt.title(title,FontSize=17)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
#plt.text(0.015,0.85, 'd)',transform=ax.transAxes,FontSize=20)
cbaxes = figure.add_axes([0.3, 0.0257, 0.015, 0.175])
cb = ax.figure.colorbar(pmesh, cax = cbaxes)


cmin = 0.; cmax = 1.5
var=Interpolated2['PHO']["annual"][3,:,:]
var = numpy.ma.masked_where(depthm<100.,var)
title = 'Phosphate (100m)' 
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r')
ax=figure.add_subplot(322)
ax.set_position([0.375,0.007,0.25,0.45])

levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(x,y,numpy.rot90(var),cmap=cmap,norm=norm)
plt.title(title,FontSize=17)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
#plt.text(0.015,0.85, 'e)',transform=ax.transAxes,FontSize=20)
cbaxes = figure.add_axes([0.625, 0.0257, 0.015, 0.175])
cb = ax.figure.colorbar(pmesh, cax = cbaxes)

cmin = 0.; cmax = 30.
var=Interpolated2['SIL']["annual"][3,:,:]
var = numpy.ma.masked_where(depthm<100.,var)
title = 'Silicate (100m)'                 
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r')
ax=figure.add_subplot(323)
ax.set_position([0.685,0.007,0.25,0.45])

levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(x,y,numpy.rot90(var),cmap=cmap,norm=norm)
plt.title(title,FontSize=17)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
#plt.text(0.015,0.85, 'f)',transform=ax.transAxes,FontSize=20)
cbaxes = figure.add_axes([0.935, 0.0257, 0.015, 0.175])
cb = ax.figure.colorbar(pmesh, cax = cbaxes)

figure.canvas.print_figure('./plots/nutrients.png')
plt.close(figure)
###
ncf = '/cluster/projects/nn2993k/ModelInput/WOA2013/Nutrients/netcdfs/woa13_all_n00_01.nc'
nc = NetCDFFile(ncf)
WOAno3 = nc.variables['n_an'][0,0,:,:]
latw = nc.variables['lat'][:]
lonw = nc.variables['lon'][:]
nc.close()
ncf = '/cluster/projects/nn2993k/ModelInput/WOA2013/Nutrients/netcdfs/woa13_all_p00_01.nc'
nc = NetCDFFile(ncf)
WOApo4 = nc.variables['p_an'][0,0,:,:]
nc.close()
ncf = '/cluster/projects/nn2993k/ModelInput/WOA2013/Nutrients/netcdfs/woa13_all_i00_01.nc'
nc = NetCDFFile(ncf)
WOAsi = nc.variables['i_an'][0,0,:,:]
nc.close()

xw1,yw1=np.meshgrid(lonw,latw)
xw,yw=m(xw1,yw1)

cmin = 0.; cmax = 15.
title = 'Nitrate (5m)' 
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r')
figure=plt.figure(figsize=(12,7))
ax=figure.add_subplot(311)
ax.set_position([0.05,0.507,0.25,0.45])

levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(xw,yw,WOAno3,cmap=cmap,norm=norm)
plt.title(title,FontSize=17)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
plt.text(0.015,0.85, 'a)',transform=ax.transAxes,FontSize=20)

cmin = 0.; cmax = 1.5
title = 'Phosphate (5m)'   
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r')
ax=figure.add_subplot(312)
ax.set_position([0.365,0.507,0.25,0.45])

levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(xw,yw,WOApo4,cmap=cmap,norm=norm)
plt.title(title,Fontsize=17)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
plt.text(0.015,0.85, 'b)',transform=ax.transAxes,FontSize=20)

cmin = 0.; cmax = 30.
title = 'Silicate (5m)'                         
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r')
ax=figure.add_subplot(313)
ax.set_position([0.685,0.507,0.25,0.45])

levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(xw,yw,WOAsi,cmap=cmap,norm=norm)
plt.title(title,FontSize=17)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
plt.text(0.015,0.85, 'c)',transform=ax.transAxes,FontSize=20)

ncf = '/cluster/projects/nn2993k/ModelInput/WOA2013/Nutrients/netcdfs/woa13_all_n00_01.nc'
nc = NetCDFFile(ncf)
WOAno3100 = nc.variables['n_an'][0,20,:,:]
latw = nc.variables['lat'][:]
lonw = nc.variables['lon'][:]
nc.close()
ncf = '/cluster/projects/nn2993k/ModelInput/WOA2013/Nutrients/netcdfs/woa13_all_p00_01.nc'
nc = NetCDFFile(ncf)
WOApho100 = nc.variables['p_an'][0,20,:,:]
nc.close()
ncf = '/cluster/projects/nn2993k/ModelInput/WOA2013/Nutrients/netcdfs/woa13_all_i00_01.nc'
nc = NetCDFFile(ncf)
WOAsi100 = nc.variables['i_an'][0,20,:,:]
nc.close()

cmin = 0.; cmax = 15.
title = 'Nitrate (100m)'      
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r')
ax=figure.add_subplot(321)
ax.set_position([0.05,0.007,0.25,0.45])

levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(xw,yw,WOAno3100,cmap=cmap,norm=norm)
plt.title(title,FontSize=17)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
#plt.text(0.015,0.85, 'd)',transform=ax.transAxes,FontSize=20)
cbaxes = figure.add_axes([0.3, 0.0257, 0.015, 0.175])
cb = ax.figure.colorbar(pmesh, cax = cbaxes)


cmin = 0.; cmax = 1.5
title = 'Phosphate (100m)' 
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r')
ax=figure.add_subplot(322)
ax.set_position([0.375,0.007,0.25,0.45])

levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(xw,yw,WOApho100,cmap=cmap,norm=norm)
plt.title(title,FontSize=17)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
#plt.text(0.015,0.85, 'e)',transform=ax.transAxes,FontSize=20)
cbaxes = figure.add_axes([0.625, 0.0257, 0.015, 0.175])
cb = ax.figure.colorbar(pmesh, cax = cbaxes)

cmin = 0.; cmax = 30.
title = 'Silicate (100m)'                 
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r')
ax=figure.add_subplot(323)
ax.set_position([0.685,0.007,0.25,0.45])

levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(xw,yw,WOAsi100,cmap=cmap,norm=norm)
plt.title(title,FontSize=17)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
#plt.text(0.015,0.85, 'f)',transform=ax.transAxes,FontSize=20)
cbaxes = figure.add_axes([0.935, 0.0257, 0.015, 0.175])
cb = ax.figure.colorbar(pmesh, cax = cbaxes)

figure.canvas.print_figure('./plots/WOAnut.png')
plt.close(figure)

# N/P ratios
figure=plt.figure(figsize=(6,6))
ax=figure.add_subplot(221)

cmin = 5.; cmax = 20.
no3=Interpolated2['NO3']["annual"][0,:,:]
no3 = numpy.ma.masked_where(depthm<5.,no3)
po4=Interpolated2['PHO']["annual"][0,:,:]
po4 = numpy.ma.masked_where(depthm<5.,po4)
title = 'Model N/P molar ratio (0m)'
levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(x,y,np.rot90(no3/po4),cmap=cmap,norm=norm)
plt.title(title,FontSize=12)
m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
plt.text(0.015,0.85, 'a)',transform=ax.transAxes,FontSize=20)

ax=figure.add_subplot(223)
cmin = 5.; cmax = 20.
no3=Interpolated2['NO3']["annual"][3,:,:]
no3 = numpy.ma.masked_where(depthm<100.,no3)
po4=Interpolated2['PHO']["annual"][3,:,:]
po4 = numpy.ma.masked_where(depthm<100.,po4)
title = 'Model N/P molar ratio (100m)'
levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(x,y,np.rot90(no3/po4),cmap=cmap,norm=norm)
plt.title(title,FontSize=12)
m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')

ax=figure.add_subplot(222)
title = 'WOA N/P molar ratio (0m)'
levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(xw,yw,WOAno3/WOApo4,cmap=cmap,norm=norm)
plt.title(title,FontSize=12)
m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
plt.text(0.015,0.85, 'b)',transform=ax.transAxes,FontSize=20)

ax=figure.add_subplot(224)
title = 'WOA N/P molar ratio (100m)'
levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(xw,yw,WOAno3100/WOApo4100,cmap=cmap,norm=norm)
plt.title(title,FontSize=12)
m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')

cbaxes = figure.add_axes([0.935, 0.0257, 0.015, 0.175])
cb = ax.figure.colorbar(pmesh, cax = cbaxes)

figure.canvas.print_figure('./plots/NPratios.png')
plt.close(figure)
### HEXAGONS ######################################
model    = Colocated2[0]["NO3"]["model"][Colocated2[0]["NO3"]["depth"]<100]
observed = Colocated2[0]["NO3"]["obsrv"][Colocated2[0]["NO3"]["depth"]<100]
model =  numpy.ma.masked_where(model<0.,model)
observed =  numpy.ma.masked_where(observed<0.,observed)


model1      = Colocated2[1]["NO3"]["model"][Colocated2[1]["NO3"]["depth"]<100]
model2      = Colocated2[2]["NO3"]["model"][Colocated2[2]["NO3"]["depth"]<100]
observed1   = Colocated2[1]["NO3"]["obsrv"][Colocated2[1]["NO3"]["depth"]<100]
observed2   = Colocated2[2]["NO3"]["obsrv"][Colocated2[2]["NO3"]["depth"]<100]
modelnor    = numpy.concatenate( (model1,model2))
observednor = numpy.concatenate( (observed1,observed2) )
modelnor    =  numpy.ma.masked_where(modelnor<0.,modelnor)
observednor =  numpy.ma.masked_where(observednor<0.,observednor)

figure=plt.figure(figsize=(10,10))

ax=figure.add_subplot(211)
ax.set_position([0.07,0.72,0.34,0.25])
ax.set_title("Barents Sea Nitrate upper 100m")
ax.set_ylabel(r"Observed ($\mu$molN L$^{-1}$)")
ax.set_xlabel(r"Modeled ($\mu$molN L$^{-1}$)") 
plt.set_cmap('binary')
hb = ax.hexbin(model, observed, gridsize=40, bins='log')
ax.axis([0,15,0,15])
plt.text(0.015,0.85, 'a)',transform=ax.transAxes,FontSize=18)
plt.plot([0,50],[0,50],Color='k')
cbaxes = figure.add_axes([0.41, 0.72, 0.02, 0.2])
cb = ax.figure.colorbar(hb, cax = cbaxes)
#cb.set_label('log10(Number of Obs.)')

ax=figure.add_subplot(212)
ax.set_position([0.56,0.72,0.34,0.25])
ax.set_title("Norwegian Sea Nitrate upper 100m")
ax.set_ylabel(r"Observed ($\mu$molN L$^{-1}$)")
ax.set_xlabel(r"Modeled ($\mu$molN L$^{-1}$)")
plt.set_cmap('binary')
hb = ax.hexbin(modelnor, observednor, gridsize=40, bins='log')
ax.axis([0,15,0,15])
plt.text(0.015,0.85, 'b)',transform=ax.transAxes,FontSize=18)
plt.plot([0,50],[0,50],Color='k')
cbaxes = figure.add_axes([0.9, 0.72, 0.02, 0.2])
cb = ax.figure.colorbar(hb, cax = cbaxes)
#cb.set_label('log10(Number of Obs.)')

model    = Colocated2[0]["SIL"]["model"][Colocated2[0]["SIL"]["depth"]<100]
observed = Colocated2[0]["SIL"]["obsrv"][Colocated2[0]["SIL"]["depth"]<100]
model =  numpy.ma.masked_where(model<0.,model)
observed =  numpy.ma.masked_where(observed<0.,observed)


model1      = Colocated2[1]["SIL"]["model"][Colocated2[1]["SIL"]["depth"]<100]
model2      = Colocated2[2]["SIL"]["model"][Colocated2[2]["SIL"]["depth"]<100]
observed1   = Colocated2[1]["SIL"]["obsrv"][Colocated2[1]["SIL"]["depth"]<100]
observed2   = Colocated2[2]["SIL"]["obsrv"][Colocated2[2]["SIL"]["depth"]<100]
modelnor    = numpy.concatenate( (model1,model2))
observednor = numpy.concatenate( (observed1,observed2) )
modelnor    =  numpy.ma.masked_where(modelnor<0.,modelnor)
observednor =  numpy.ma.masked_where(observednor<0.,observednor)

ax=figure.add_subplot(221)
ax.set_position([0.07,0.38,0.34,0.25])
ax.set_title("Barents Sea Silicate upper 100m")
ax.set_ylabel(r"Observed ($\mu$molSi L$^{-1}$)")
ax.set_xlabel(r"Modeled ($\mu$molSi L$^{-1}$)")
plt.set_cmap('binary')
hb = ax.hexbin(model, observed, gridsize=40, bins='log')
ax.axis([0,10,0,10])
plt.text(0.015,0.85, 'c)',transform=ax.transAxes,FontSize=18)
plt.plot([0,50],[0,50],Color='k')
cbaxes = figure.add_axes([0.41, 0.38, 0.02, 0.2])
cb = ax.figure.colorbar(hb, cax = cbaxes)
#cb.set_label('log10(Number of Obs.)')

ax=figure.add_subplot(222)
ax.set_position([0.56,0.38,0.34,0.25])
ax.set_title("Norwegian Sea Silicate upper 100m")
ax.set_ylabel(r"Observed ($\mu$molSi L$^{-1}$)")
ax.set_xlabel(r"Modeled ($\mu$molSi L$^{-1}$)")
plt.set_cmap('binary')
hb = ax.hexbin(modelnor, observednor, gridsize=40, bins='log')
ax.axis([0,10,0,10])
plt.text(0.015,0.85, 'd)',transform=ax.transAxes,FontSize=18)
plt.plot([0,50],[0,50],Color='k')
cbaxes = figure.add_axes([0.9, 0.38, 0.02, 0.2])
cb = ax.figure.colorbar(hb, cax = cbaxes)
#cb.set_label('log10(Number of Obs.)')

model    = Colocated2[0]["CHL"]["model"][Colocated2[0]["CHL"]["depth"]<100]
observed = Colocated2[0]["CHL"]["obsrv"][Colocated2[0]["CHL"]["depth"]<100]
model =  numpy.ma.masked_where(model<0.,model)
observed =  numpy.ma.masked_where(observed<0.,observed)

model = numpy.log10(model)
observed = numpy.log10(observed)

model1      = Colocated2[1]["CHL"]["model"][Colocated2[1]["CHL"]["depth"]<100]
model2      = Colocated2[2]["CHL"]["model"][Colocated2[2]["CHL"]["depth"]<100]
observed1   = Colocated2[1]["CHL"]["obsrv"][Colocated2[1]["CHL"]["depth"]<100]
observed2   = Colocated2[2]["CHL"]["obsrv"][Colocated2[2]["CHL"]["depth"]<100]
modelnor    = numpy.concatenate( (model1,model2))
observednor = numpy.concatenate( (observed1,observed2) )
modelnor    =  numpy.ma.masked_where(modelnor<0.,modelnor)
observednor =  numpy.ma.masked_where(observednor<0.,observednor)

modelnor = numpy.log10(modelnor)
observednor = numpy.log10(observednor)

ax=figure.add_subplot(231)
ax.set_position([0.07,0.05,0.34,0.25])
ax.set_title("Barents Sea $log_{10}$(Chlorophyll a) upper 100m")
ax.set_ylabel(r"Observed ($log_{10}(\mu$g L$^{-1})$)")
ax.set_xlabel(r"Modeled ($log_{10}(\mu$g L$^{-1})$)")
plt.set_cmap('binary')
hb = ax.hexbin(model, observed, gridsize=40, bins='log')
ax.axis([-3,1,-3,1])
plt.text(0.015,0.85, 'e)',transform=ax.transAxes,FontSize=18)
plt.plot([-3,1],[-3,1],Color='k')
cbaxes = figure.add_axes([0.41, 0.05, 0.02, 0.2])
cb = ax.figure.colorbar(hb, cax = cbaxes)
#cb.set_label('log10(Number of Obs.)')

ax=figure.add_subplot(232)
ax.set_position([0.56,0.05,0.34,0.25])
ax.set_title("Norwegian Sea $log_{10}$(Chlorophyll a) upper 100m")
ax.set_ylabel(r"Observed ($log_{10}(\mu$g L$^{-1})$)")
ax.set_xlabel(r"Modeled ($log_{10}(\mu$g L$^{-1})$)")
plt.set_cmap('binary')
hb = ax.hexbin(modelnor, observednor, gridsize=40, bins='log')
ax.axis([-3,1,-3,1])
plt.text(0.015,0.85, 'f)',transform=ax.transAxes,FontSize=18)
plt.plot([-3,1],[-3,1],Color='k')
cbaxes = figure.add_axes([0.9, 0.05, 0.02, 0.2])
cb = ax.figure.colorbar(hb, cax = cbaxes)
#cb.set_label('log10(Number of Obs.)')

figure.canvas.print_figure('./plots/hexplot.png')
plt.close(figure)
#################################################
inputpath  = './%s'
WOAaverages = sio.loadmat(inputpath%('regional_averages_WOA.mat'))
masksread = sio.loadmat(inputpath%('masksNA2.mat'))
masks = numpy.zeros(( 11, masksread['maskBARENTS'].T.shape[0], masksread['maskBARENTS'].T.shape[1] ))
masks[0,:,:] = masksread['maskBARENTS'].T
masks[1,:,:] = masksread['maskNORWEGIAN1'].T
masks[2,:,:] = masksread['maskNORWEGIAN2'].T
masks[3,:,:] = masksread['maskARCTIC1'].T
masks[4,:,:] = masksread['maskARCTIC2'].T
masks[5,:,:] = masksread['maskARCTIC3'].T
masks[6,:,:] = masksread['maskARCTIC4'].T
masks[7,:,:] = masksread['maskGREENLAND'].T
masks[8,:,:] = masksread['maskBER'].T
masks[9,:,:] = masksread['maskKARA'].T
masks[10,:,:] = masksread['maskSPG'].T


names  = ['Barents','NorwegianN','NorwegianS','ArcAtl','Laptev','ArcEast','ArcCan','Greenland','Bering','Kara','SPG']
subs = ['a)','b)','c)','d)','e)','f)']
nutrients = ['Nitrate','Silicate','Phosphate']
depths2 = ['5m','100m']
mmm=0
figure=plt.figure(figsize=(15,6.5))
for mnut in ['NO3','SIL','PHO']:
  OBSave=numpy.zeros((2,12))
  OBSstd=numpy.zeros((2,12))
  MODave=numpy.zeros((3,2,12))
  MODstd=numpy.zeros((3,2,12))
#  figure=plt.figure(figsize=(10,5.5))
#  figure.suptitle('Model vs WOA Nutrient Regional Average Timeseries',fontsize=15)
  rr= [0,2,10]
  if mnut == 'NO3':
      onut='nit'
  if mnut == 'SIL' :
      onut = 'sil'
  if mnut == 'PHO' :
      onut = 'pho'

  ttt=0
  for r in range(3):
   for m in range(12):
    OBSave[0,m] = WOAaverages['region_WOAmonth'][0][rr[r]]['ave'][onut][0][0][m][1]
    OBSstd[0,m] = WOAaverages['region_WOAmonth'][0][rr[r]]['std'][onut][0][0][m][1]
    MODave[0,0,m] = numpy.nanmean(Interpolated1[mnut]["monthly"][m,0,:,:][masks[rr[r],:,:]==1])
    MODstd[0,0,m] = numpy.nanstd(Interpolated1[mnut]["monthly"][m,0,:,:][masks[rr[r],:,:]==1])
    MODave[1,0,m] = numpy.nanmean(Interpolated2[mnut]["monthly"][m,0,:,:][masks[rr[r],:,:]==1])
    MODstd[1,0,m] = numpy.nanstd(Interpolated2[mnut]["monthly"][m,0,:,:][masks[rr[r],:,:]==1])
    MODave[2,0,m] = numpy.nanmean(Interpolated3[mnut]["monthly"][m,0,:,:][masks[rr[r],:,:]==1])
    MODstd[2,0,m] = numpy.nanstd(Interpolated3[mnut]["monthly"][m,0,:,:][masks[rr[r],:,:]==1])

    OBSave[1,m] = WOAaverages['region_WOAmonth'][0][rr[r]]['ave'][onut][0][0][m][20]
    OBSstd[1,m] = WOAaverages['region_WOAmonth'][0][rr[r]]['std'][onut][0][0][m][20]
    MODave[0,1,m] = numpy.nanmean(Interpolated1[mnut]["monthly"][m,3,:,:][masks[rr[r],:,:]==1])
    MODstd[0,1,m] = numpy.nanstd(Interpolated1[mnut]["monthly"][m,3,:,:][masks[rr[r],:,:]==1])
    MODave[1,1,m] = numpy.nanmean(Interpolated2[mnut]["monthly"][m,3,:,:][masks[rr[r],:,:]==1])
    MODstd[1,1,m] = numpy.nanstd(Interpolated2[mnut]["monthly"][m,3,:,:][masks[rr[r],:,:]==1])
    MODave[2,1,m] = numpy.nanmean(Interpolated3[mnut]["monthly"][m,3,:,:][masks[rr[r],:,:]==1])
    MODstd[2,1,m] = numpy.nanstd(Interpolated3[mnut]["monthly"][m,3,:,:][masks[rr[r],:,:]==1])

   for d in range(2):
# ax=figure.add_subplot(4,5,d*5+s1)
    ax=figure.add_subplot(3,6,r*6+1+d+mmm*2)
    if ( mnut == 'NO3' ) or ( mnut == 'SIL' ):
      ax.axis([0, 13, 0, 18])
    else:
      ax.axis([0, 13, 0, 1.25])

    for m in range(12):
        plt.plot([m+1,m+1],[OBSave[d,m]-OBSstd[d,m],OBSave[d,m]+OBSstd[d,m] ],color='grey', linewidth=2)
    plt.plot(numpy.arange(12)+1,OBSave[d,:],color='grey', linewidth=2, label='WOA')
    for m in range(12):
        plt.plot([m+1,m+1],[MODave[1,d,m]-MODstd[1,d,m],MODave[1,d,m]+MODstd[1,d,m] ],color='black', linewidth=2)
    plt.plot(numpy.arange(12)+1,MODave[1,d,:],color='black', linewidth=2, label='EXP1')
    for m in range(12):
        plt.plot([m+1,m+1],[MODave[0,d,m]-MODstd[0,d,m],MODave[0,d,m]+MODstd[0,d,m] ],color='black', linewidth=2,linestyle='--')
    plt.plot(numpy.arange(12)+1,MODave[0,d,:],color='black', linewidth=2, label='EXP2',linestyle='--')
    for m in range(12):
        plt.plot([m+1,m+1],[MODave[2,d,m]-MODstd[2,d,m],MODave[2,d,m]+MODstd[2,d,m] ],color='black', linewidth=2,linestyle=':')
    plt.plot(numpy.arange(12)+1,MODave[2,d,:],color='black', linewidth=2, label='EXP3',linestyle=':')

#    plt.text(0.015,0.9, subs[ttt],transform=ax.transAxes,FontSize=14)
    plt.text(0.05,0.9,names[rr[r]]+ ' '+depths2[d],transform=ax.transAxes,fontsize=12)
    if (r==0) & (d==0):
       plt.text(0.85,1.1,nutrients[mmm],transform=ax.transAxes,FontSize=16)
       plt.text(-0.05,1.05,subs[mmm],transform=ax.transAxes,FontSize=14)
    if (mmm==0) & (d==0) :
       ax.set_ylabel(r'$\mu$mol/m$^{-3}$',fontsize=12)
    if r<2 :
       plt.xticks([])
    else:
       plt.xticks([1,3,5,7,9,11])
    if r==2 :
       ax.set_xlabel('months',fontsize=14)

    ttt=ttt+1
  mmm=mmm+1
ax.legend(prop={'size': 8})
figure.canvas.print_figure('./plots/vsWOA.png')
plt.close(figure)
# NUMBER OF WOA OBSERVATION PLOTS
N = sio.loadmat('nobsWOApaper.mat')
rr= [0,2,10]
names  = ['Barents','NorwegianN','NorwegianS','ArcAtl','Laptev','ArcEast','ArcCan','Greenland','Bering','Kara','SPG']
subs = ['a)','b)','c)','d)','e)','f)']
nutrients = ['Nitrate','Silicate','Phosphate']
depths2 = ['5m','100m']
mmm = 0

figure=plt.figure(figsize=(15,6.5))
for m in range(18):
  ax=figure.add_subplot(3,6,m+1)
  plt.plot(numpy.arange(12)+1,N['nobs'][m,:],color='black', linewidth=2,label='Nprofiles')
  plt.plot(numpy.arange(12)+1,N['nobs'][m+18,:],color='grey', linewidth=2,label='Nlocations')
  if m<=5:
   regionname=names[0]
   if ((m % 2)  ==0) or m==0:
     plt.text(0.85,1.1,nutrients[mmm],transform=ax.transAxes,FontSize=16)
     plt.text(-0.05,1.05,subs[mmm],transform=ax.transAxes,FontSize=14)
     mmm = mmm + 1
  elif m>=12:
   regionname=names[10]
  else:
   regionname=names[2]
  if ((m % 2)  ==0) or m==0:
   depthname = depths2[0]
  else:
   depthname = depths2[1]
  plt.text(0.05,0.9,regionname+ ' '+depthname,transform=ax.transAxes,fontsize=12)
  if (m==0) or (m==6) or (m==12):
   ax.set_ylabel('# of obs.')
  else:
   plt.yticks([])
  if m<12:
   plt.xticks([])
  else:
   plt.xticks([1,3,5,7,9,11])
   ax.set_xlabel('months',fontsize=14)
  ax.axis([0, 13, 0, 2000])
  if m==17:
   ax.legend(prop={'size': 8},loc='center right')

figure.canvas.print_figure('./plots/vsWOAnobs.png')
plt.close(figure)
################################
DIAave=numpy.zeros((numpy.size(names),12))
FLAave=numpy.zeros((numpy.size(names),12))
MICave=numpy.zeros((numpy.size(names),12))
MESave=numpy.zeros((numpy.size(names),12))

for r in range(numpy.size(names)):
  for m in range(12):
     DIAave[r,m] = numpy.nanmean(numpy.nanmean(ALGAE2['DIA']['monthly'][m,:,:][masks[r,:,:]==1]))
     FLAave[r,m] = numpy.nanmean(numpy.nanmean(ALGAE2['FLA']['monthly'][m,:,:][masks[r,:,:]==1]))
     MICave[r,m] = numpy.nanmean(numpy.nanmean(ALGAE2['MIC']['monthly'][m,:,:][masks[r,:,:]==1]))
     MESave[r,m] = numpy.nanmean(numpy.nanmean(ALGAE2['MES']['monthly'][m,:,:][masks[r,:,:]==1]))
###############################

Stat1 = {}; Stat2 = {}; Stat3 = {}
subregion  = ['Barents','NorwegianN','NorwegianS']
for item in range( numpy.size(subregion) ):

  Stat1[item] =  {'NO3' : { 'corr': -999., 'std' : -999., 'bias' : -999., 'rmse' : -999., 'me' : -999.}, \
                 'SIL' : { 'corr': -999., 'std' : -999., 'bias' : -999., 'rmse' : -999., 'me' : -999. }, \
                 'PHO' : { 'corr': -999., 'std' : -999., 'bias' : -999., 'rmse' : -999., 'me' : -999. }, \
                 'CHL' : { 'corr': -999., 'std' : -999., 'bias' : -999., 'rmse' : -999., 'me' : -999. }, \
                 'OXY' : { 'corr': -999., 'std' : -999., 'bias' : -999., 'rmse' : -999., 'me' : -999. } }

  Stat2[item] =  {'NO3' : { 'corr': -999., 'std' : -999., 'bias' : -999., 'rmse' : -999., 'me' : -999. }, \
                 'SIL' : { 'corr': -999., 'std' : -999., 'bias' : -999., 'rmse' : -999., 'me' : -999. }, \
                 'PHO' : { 'corr': -999., 'std' : -999., 'bias' : -999., 'rmse' : -999., 'me' : -999. }, \
                 'CHL' : { 'corr': -999., 'std' : -999., 'bias' : -999., 'rmse' : -999., 'me' : -999. }, \
                 'OXY' : { 'corr': -999., 'std' : -999., 'bias' : -999., 'rmse' : -999., 'me' : -999. } }

  Stat3[item] =  {'NO3' : { 'corr': -999., 'std' : -999., 'bias' : -999., 'rmse' : -999., 'me' : -999. }, \
                 'SIL' : { 'corr': -999., 'std' : -999., 'bias' : -999., 'rmse' : -999., 'me' : -999. }, \
                 'PHO' : { 'corr': -999., 'std' : -999., 'bias' : -999., 'rmse' : -999., 'me' : -999. }, \
                 'CHL' : { 'corr': -999., 'std' : -999., 'bias' : -999., 'rmse' : -999., 'me' : -999. }, \
                 'OXY' : { 'corr': -999., 'std' : -999., 'bias' : -999., 'rmse' : -999., 'me' : -999. } }

tableno31 = PrettyTable(['Region', 'CorrCoef', 'Norm. StdDev', 'Bias', 'RMSE', 'ModEff'])
tablesil1 = PrettyTable(['Region', 'CorrCoef', 'Norm. StdDev', 'Bias', 'RMSE', 'ModEff'])
tablepho1 = PrettyTable(['Region', 'CorrCoef', 'Norm. StdDev', 'Bias', 'RMSE', 'ModEff'])
tablechl1 = PrettyTable(['Region', 'CorrCoef', 'Norm. StdDev', 'Bias', 'RMSE', 'ModEff'])
tableno32 = PrettyTable(['Region', 'CorrCoef', 'Norm. StdDev', 'Bias', 'RMSE', 'ModEff'])
tablesil2 = PrettyTable(['Region', 'CorrCoef', 'Norm. StdDev', 'Bias', 'RMSE', 'ModEff'])
tablepho2 = PrettyTable(['Region', 'CorrCoef', 'Norm. StdDev', 'Bias', 'RMSE', 'ModEff'])
tablechl2 = PrettyTable(['Region', 'CorrCoef', 'Norm. StdDev', 'Bias', 'RMSE', 'ModEff'])
tableno33 = PrettyTable(['Region', 'CorrCoef', 'Norm. StdDev', 'Bias', 'RMSE', 'ModEff'])
tablesil3 = PrettyTable(['Region', 'CorrCoef', 'Norm. StdDev', 'Bias', 'RMSE', 'ModEff'])
tablepho3 = PrettyTable(['Region', 'CorrCoef', 'Norm. StdDev', 'Bias', 'RMSE', 'ModEff'])
tablechl3 = PrettyTable(['Region', 'CorrCoef', 'Norm. StdDev', 'Bias', 'RMSE', 'ModEff'])

for r in range( numpy.size(subregion) ):
  n = Colocated1[r]["NO3"]["obsrv"].shape[0]
  Stat1[r]['NO3']['corr'] = correlation(Colocated1[r]["NO3"]["model"][1:n],Colocated1[r]["NO3"]["obsrv"][1:n])
  Stat1[r]['NO3']['std'] = nstd(Colocated1[r]["NO3"]["model"][1:n],Colocated1[r]["NO3"]["obsrv"][1:n])
  Stat1[r]['NO3']['rmse'] = rmse(Colocated1[r]["NO3"]["model"][1:n],Colocated1[r]["NO3"]["obsrv"][1:n])
  Stat1[r]['NO3']['bias'] = pc_bias(Colocated1[r]["NO3"]["model"][1:n],Colocated1[r]["NO3"]["obsrv"][1:n])
  Stat1[r]['NO3']['me'] = me(Colocated1[r]["NO3"]["model"][1:n],Colocated1[r]["NO3"]["obsrv"][1:n])
  n = Colocated1[r]["SIL"]["obsrv"].shape[0]
  Stat1[r]['SIL']['corr'] = correlation(Colocated1[r]["SIL"]["model"][1:n],Colocated1[r]["SIL"]["obsrv"][1:n])
  Stat1[r]['SIL']['std'] = nstd(Colocated1[r]["SIL"]["model"][1:n],Colocated1[r]["SIL"]["obsrv"][1:n])
  Stat1[r]['SIL']['rmse'] = rmse(Colocated1[r]["SIL"]["model"][1:n],Colocated1[r]["SIL"]["obsrv"][1:n])
  Stat1[r]['SIL']['bias'] = pc_bias(Colocated1[r]["SIL"]["model"][1:n],Colocated1[r]["SIL"]["obsrv"][1:n])
  Stat1[r]['SIL']['me'] = me(Colocated1[r]["SIL"]["model"][1:n],Colocated1[r]["SIL"]["obsrv"][1:n])
  n = Colocated1[r]["PHO"]["obsrv"].shape[0] 
  Stat1[r]['PHO']['corr'] = correlation(Colocated1[r]["PHO"]["model"][1:n],Colocated1[r]["PHO"]["obsrv"][1:n])
  Stat1[r]['PHO']['std'] = nstd(Colocated1[r]["PHO"]["model"][1:n],Colocated1[r]["PHO"]["obsrv"][1:n])
  Stat1[r]['PHO']['rmse'] = rmse(Colocated1[r]["PHO"]["model"][1:n],Colocated1[r]["PHO"]["obsrv"][1:n])
  Stat1[r]['PHO']['bias'] = pc_bias(Colocated1[r]["PHO"]["model"][1:n],Colocated1[r]["PHO"]["obsrv"][1:n])
  Stat1[r]['PHO']['me'] = me(Colocated1[r]["PHO"]["model"][1:n],Colocated1[r]["PHO"]["obsrv"][1:n])
  n = Colocated1[r]["CHL"]["obsrv"].shape[0]
  Colocated1[r]["CHL"]["obsrv"][Colocated1[r]["CHL"]["obsrv"]<=0.] = 1E-10
#  Stat1[r]['CHL']['corr'] = correlation(numpy.log10(Colocated1[r]["CHL"]["model"][1:n]),numpy.log10(Colocated1[r]["CHL"]["obsrv"][1:n]))
#  Stat1[r]['CHL']['std'] = nstd(numpy.log10(Colocated1[r]["CHL"]["model"][1:n]),numpy.log10(Colocated1[r]["CHL"]["obsrv"][1:n]))
#  Stat1[r]['CHL']['rmse'] = rmse(numpy.log10(Colocated1[r]["CHL"]["model"][1:n]),numpy.log10(Colocated1[r]["CHL"]["obsrv"][1:n]))
#  Stat1[r]['CHL']['bias'] = pc_bias(numpy.log10(Colocated1[r]["CHL"]["model"][1:n]),numpy.log10(Colocated1[r]["CHL"]["obsrv"][1:n]))
#  Stat1[r]['CHL']['me'] = me(numpy.log10(Colocated1[r]["CHL"]["model"][1:n]),numpy.log10(Colocated1[r]["CHL"]["obsrv"][1:n]))

  Stat1[r]['CHL']['corr'] = correlation((Colocated1[r]["CHL"]["model"][1:n]),(Colocated1[r]["CHL"]["obsrv"][1:n]))
  Stat1[r]['CHL']['std'] = nstd((Colocated1[r]["CHL"]["model"][1:n]),(Colocated1[r]["CHL"]["obsrv"][1:n]))
  Stat1[r]['CHL']['rmse'] = rmse((Colocated1[r]["CHL"]["model"][1:n]),(Colocated1[r]["CHL"]["obsrv"][1:n]))
  Stat1[r]['CHL']['bias'] = pc_bias((Colocated1[r]["CHL"]["model"][1:n]),(Colocated1[r]["CHL"]["obsrv"][1:n]))
  Stat1[r]['CHL']['me'] = me((Colocated1[r]["CHL"]["model"][1:n]),(Colocated1[r]["CHL"]["obsrv"][1:n]))

  n = Colocated2[r]["NO3"]["obsrv"].shape[0]
  Stat2[r]['NO3']['corr'] = correlation(Colocated2[r]["NO3"]["model"][1:n],Colocated2[r]["NO3"]["obsrv"][1:n])
  Stat2[r]['NO3']['std'] = nstd(Colocated2[r]["NO3"]["model"][1:n],Colocated2[r]["NO3"]["obsrv"][1:n])
  Stat2[r]['NO3']['rmse'] = rmse(Colocated2[r]["NO3"]["model"][1:n],Colocated2[r]["NO3"]["obsrv"][1:n])
  Stat2[r]['NO3']['bias'] = pc_bias(Colocated2[r]["NO3"]["model"][1:n],Colocated2[r]["NO3"]["obsrv"][1:n])
  Stat2[r]['NO3']['me'] = me(Colocated2[r]["NO3"]["model"][1:n],Colocated2[r]["NO3"]["obsrv"][1:n])
  n = Colocated2[r]["SIL"]["obsrv"].shape[0]
  Stat2[r]['SIL']['corr'] = correlation(Colocated2[r]["SIL"]["model"][1:n],Colocated2[r]["SIL"]["obsrv"][1:n])
  Stat2[r]['SIL']['std'] = nstd(Colocated2[r]["SIL"]["model"][1:n],Colocated2[r]["SIL"]["obsrv"][1:n])
  Stat2[r]['SIL']['rmse'] = rmse(Colocated2[r]["SIL"]["model"][1:n],Colocated2[r]["SIL"]["obsrv"][1:n])
  Stat2[r]['SIL']['bias'] = pc_bias(Colocated2[r]["SIL"]["model"][1:n],Colocated2[r]["SIL"]["obsrv"][1:n])
  Stat2[r]['SIL']['me'] = me(Colocated2[r]["SIL"]["model"][1:n],Colocated2[r]["SIL"]["obsrv"][1:n])
  n = Colocated2[r]["PHO"]["obsrv"].shape[0]
  Stat2[r]['PHO']['corr'] = correlation(Colocated2[r]["PHO"]["model"][1:n],Colocated2[r]["PHO"]["obsrv"][1:n])
  Stat2[r]['PHO']['std'] = nstd(Colocated2[r]["PHO"]["model"][1:n],Colocated2[r]["PHO"]["obsrv"][1:n])
  Stat2[r]['PHO']['rmse'] = rmse(Colocated2[r]["PHO"]["model"][1:n],Colocated2[r]["PHO"]["obsrv"][1:n])
  Stat2[r]['PHO']['bias'] = pc_bias(Colocated2[r]["PHO"]["model"][1:n],Colocated2[r]["PHO"]["obsrv"][1:n])
  Stat2[r]['PHO']['me'] = me(Colocated2[r]["PHO"]["model"][1:n],Colocated2[r]["PHO"]["obsrv"][1:n])
  n = Colocated2[r]["CHL"]["obsrv"].shape[0]
  Colocated2[r]["CHL"]["obsrv"][Colocated2[r]["CHL"]["obsrv"]<=0.] = 1E-10
#  Stat2[r]['CHL']['corr'] = correlation(numpy.log10(Colocated2[r]["CHL"]["model"][1:n]),numpy.log10(Colocated2[r]["CHL"]["obsrv"][1:n]))
#  Stat2[r]['CHL']['std'] = nstd(numpy.log10(Colocated2[r]["CHL"]["model"][1:n]),numpy.log10(Colocated2[r]["CHL"]["obsrv"][1:n]))
#  Stat2[r]['CHL']['rmse'] = rmse(numpy.log10(Colocated2[r]["CHL"]["model"][1:n]),numpy.log10(Colocated2[r]["CHL"]["obsrv"][1:n]))
#  Stat2[r]['CHL']['bias'] = pc_bias(numpy.log10(Colocated2[r]["CHL"]["model"][1:n]),numpy.log10(Colocated2[r]["CHL"]["obsrv"][1:n]))
#  Stat2[r]['CHL']['me'] = me(numpy.log10(Colocated2[r]["CHL"]["model"][1:n]),numpy.log10(Colocated2[r]["CHL"]["obsrv"][1:n]))

  Stat2[r]['CHL']['corr'] = correlation((Colocated2[r]["CHL"]["model"][1:n]),(Colocated2[r]["CHL"]["obsrv"][1:n]))
  Stat2[r]['CHL']['std'] = nstd((Colocated2[r]["CHL"]["model"][1:n]),(Colocated2[r]["CHL"]["obsrv"][1:n]))
  Stat2[r]['CHL']['rmse'] = rmse((Colocated2[r]["CHL"]["model"][1:n]),(Colocated2[r]["CHL"]["obsrv"][1:n]))
  Stat2[r]['CHL']['bias'] = pc_bias((Colocated2[r]["CHL"]["model"][1:n]),(Colocated2[r]["CHL"]["obsrv"][1:n]))
  Stat2[r]['CHL']['me'] = me((Colocated2[r]["CHL"]["model"][1:n]),(Colocated2[r]["CHL"]["obsrv"][1:n]))

  n = Colocated3[r]["NO3"]["obsrv"].shape[0]
  Stat3[r]['NO3']['corr'] = correlation(Colocated3[r]["NO3"]["model"][1:n],Colocated3[r]["NO3"]["obsrv"][1:n])
  Stat3[r]['NO3']['std'] = nstd(Colocated3[r]["NO3"]["model"][1:n],Colocated3[r]["NO3"]["obsrv"][1:n])
  Stat3[r]['NO3']['rmse'] = rmse(Colocated3[r]["NO3"]["model"][1:n],Colocated3[r]["NO3"]["obsrv"][1:n])
  Stat3[r]['NO3']['bias'] = pc_bias(Colocated3[r]["NO3"]["model"][1:n],Colocated3[r]["NO3"]["obsrv"][1:n])
  Stat3[r]['NO3']['me'] = me(Colocated3[r]["NO3"]["model"][1:n],Colocated3[r]["NO3"]["obsrv"][1:n])
  n = Colocated3[r]["SIL"]["obsrv"].shape[0]
  Stat3[r]['SIL']['corr'] = correlation(Colocated3[r]["SIL"]["model"][1:n],Colocated3[r]["SIL"]["obsrv"][1:n])
  Stat3[r]['SIL']['std'] = nstd(Colocated3[r]["SIL"]["model"][1:n],Colocated3[r]["SIL"]["obsrv"][1:n])
  Stat3[r]['SIL']['rmse'] = rmse(Colocated3[r]["SIL"]["model"][1:n],Colocated3[r]["SIL"]["obsrv"][1:n])
  Stat3[r]['SIL']['bias'] = pc_bias(Colocated3[r]["SIL"]["model"][1:n],Colocated3[r]["SIL"]["obsrv"][1:n])
  Stat3[r]['SIL']['me'] = me(Colocated3[r]["SIL"]["model"][1:n],Colocated3[r]["SIL"]["obsrv"][1:n])
  n = Colocated3[r]["PHO"]["obsrv"].shape[0]
  Stat3[r]['PHO']['corr'] = correlation(Colocated3[r]["PHO"]["model"][1:n],Colocated3[r]["PHO"]["obsrv"][1:n])
  Stat3[r]['PHO']['std'] = nstd(Colocated3[r]["PHO"]["model"][1:n],Colocated3[r]["PHO"]["obsrv"][1:n])
  Stat3[r]['PHO']['rmse'] = rmse(Colocated3[r]["PHO"]["model"][1:n],Colocated3[r]["PHO"]["obsrv"][1:n])
  Stat3[r]['PHO']['bias'] = pc_bias(Colocated3[r]["PHO"]["model"][1:n],Colocated3[r]["PHO"]["obsrv"][1:n])
  Stat3[r]['PHO']['me'] = me(Colocated3[r]["PHO"]["model"][1:n],Colocated3[r]["PHO"]["obsrv"][1:n])
  n = Colocated3[r]["CHL"]["obsrv"].shape[0]
#  Colocated3[r]["CHL"]["obsrv"][Colocated3[r]["CHL"]["obsrv"]<=0.] = 1E-10
#  Stat3[r]['CHL']['corr'] = correlation(numpy.log10(Colocated3[r]["CHL"]["model"][1:n]),numpy.log10(Colocated3[r]["CHL"]["obsrv"][1:n]))
#  Stat3[r]['CHL']['std'] = nstd(numpy.log10(Colocated3[r]["CHL"]["model"][1:n]),numpy.log10(Colocated3[r]["CHL"]["obsrv"][1:n]))
#  Stat3[r]['CHL']['rmse'] = rmse(numpy.log10(Colocated3[r]["CHL"]["model"][1:n]),numpy.log10(Colocated3[r]["CHL"]["obsrv"][1:n]))
#  Stat3[r]['CHL']['bias'] = pc_bias(numpy.log10(Colocated3[r]["CHL"]["model"][1:n]),numpy.log10(Colocated3[r]["CHL"]["obsrv"][1:n]))
#  Stat3[r]['CHL']['me'] = me(numpy.log10(Colocated3[r]["CHL"]["model"][1:n]),numpy.log10(Colocated3[r]["CHL"]["obsrv"][1:n]))

  Stat3[r]['CHL']['corr'] = correlation((Colocated3[r]["CHL"]["model"][1:n]),(Colocated3[r]["CHL"]["obsrv"][1:n]))
  Stat3[r]['CHL']['std'] = nstd((Colocated3[r]["CHL"]["model"][1:n]),(Colocated3[r]["CHL"]["obsrv"][1:n]))
  Stat3[r]['CHL']['rmse'] = rmse((Colocated3[r]["CHL"]["model"][1:n]),(Colocated3[r]["CHL"]["obsrv"][1:n]))
  Stat3[r]['CHL']['bias'] = pc_bias((Colocated3[r]["CHL"]["model"][1:n]),(Colocated3[r]["CHL"]["obsrv"][1:n]))
  Stat3[r]['CHL']['me'] = me((Colocated3[r]["CHL"]["model"][1:n]),(Colocated3[r]["CHL"]["obsrv"][1:n]))


  tableno31.add_row([subregion[r], Stat1[r]['NO3']['corr'], Stat1[r]['NO3']['std'],Stat1[r]['NO3']['bias'], Stat1[r]['NO3']['rmse'], Stat1[r]['NO3']['me'] ])
  tablesil1.add_row([subregion[r], Stat1[r]['SIL']['corr'], Stat1[r]['SIL']['std'],Stat1[r]['SIL']['bias'], Stat1[r]['SIL']['rmse'], Stat1[r]['SIL']['me'] ])
  tablepho1.add_row([subregion[r], Stat1[r]['PHO']['corr'], Stat1[r]['PHO']['std'],Stat1[r]['PHO']['bias'], Stat1[r]['PHO']['rmse'], Stat1[r]['PHO']['me'] ])
  tablechl1.add_row([subregion[r], Stat1[r]['CHL']['corr'], Stat1[r]['CHL']['std'],Stat1[r]['CHL']['bias'], Stat1[r]['CHL']['rmse'], Stat1[r]['CHL']['me'] ])

  tableno32.add_row([subregion[r], Stat2[r]['NO3']['corr'], Stat2[r]['NO3']['std'],Stat2[r]['NO3']['bias'], Stat2[r]['NO3']['rmse'], Stat2[r]['NO3']['me'] ])
  tablesil2.add_row([subregion[r], Stat2[r]['SIL']['corr'], Stat2[r]['SIL']['std'],Stat2[r]['SIL']['bias'], Stat2[r]['SIL']['rmse'], Stat2[r]['SIL']['me'] ])
  tablepho2.add_row([subregion[r], Stat2[r]['PHO']['corr'], Stat2[r]['PHO']['std'],Stat2[r]['PHO']['bias'], Stat2[r]['PHO']['rmse'], Stat2[r]['PHO']['me'] ])
  tablechl2.add_row([subregion[r], Stat2[r]['CHL']['corr'], Stat2[r]['CHL']['std'],Stat2[r]['CHL']['bias'], Stat2[r]['CHL']['rmse'], Stat2[r]['CHL']['me'] ])

  tableno33.add_row([subregion[r], Stat3[r]['NO3']['corr'], Stat3[r]['NO3']['std'],Stat3[r]['NO3']['bias'], Stat3[r]['NO3']['rmse'], Stat3[r]['NO3']['me'] ])
  tablesil3.add_row([subregion[r], Stat3[r]['SIL']['corr'], Stat3[r]['SIL']['std'],Stat3[r]['SIL']['bias'], Stat3[r]['SIL']['rmse'], Stat3[r]['SIL']['me'] ])
  tablepho3.add_row([subregion[r], Stat3[r]['PHO']['corr'], Stat3[r]['PHO']['std'],Stat3[r]['PHO']['bias'], Stat3[r]['PHO']['rmse'], Stat3[r]['PHO']['me'] ])
  tablechl3.add_row([subregion[r], Stat3[r]['CHL']['corr'], Stat3[r]['CHL']['std'],Stat3[r]['CHL']['bias'], Stat3[r]['CHL']['rmse'], Stat3[r]['CHL']['me'] ])

txtno31 = tableno31.get_string()
txtsil1 = tablesil1.get_string()
txtpho1 = tablepho1.get_string()
txtchl1 = tablechl1.get_string()

txtno32 = tableno32.get_string()
txtsil2 = tablesil2.get_string()
txtpho2 = tablepho2.get_string()
txtchl2 = tablechl2.get_string()

txtno33 = tableno33.get_string()
txtsil3 = tablesil3.get_string()
txtpho3 = tablepho3.get_string()
txtchl3 = tablechl3.get_string()

with open("./plots/NUTstat_expt020_orig.txt",'w') as file:
  file.write('expt020' + os.linesep)
  file.write(' ' + os.linesep)
  file.write('NO3' + os.linesep)
  file.write(txtno31 + os.linesep)
  file.write(' ' + os.linesep)
  file.write('SIL' + os.linesep)
  file.write(txtsil1 + os.linesep)
  file.write(' ' + os.linesep)
  file.write('PHO' + os.linesep)
  file.write(txtpho1 + os.linesep)
  file.write(' ' + os.linesep)
  file.write('CHL' + os.linesep)
  file.write(txtchl1 + os.linesep)
  file.write(' ' + os.linesep)
file.close()

with open("./plots/NUTstat_expt021_orig.txt",'w') as file:
  file.write('expt021' + os.linesep)
  file.write(' ' + os.linesep)
  file.write('NO3' + os.linesep)
  file.write(txtno32 + os.linesep)
  file.write(' ' + os.linesep)
  file.write('SIL' + os.linesep)
  file.write(txtsil2 + os.linesep)
  file.write(' ' + os.linesep)
  file.write('PHO' + os.linesep)
  file.write(txtpho2 + os.linesep)
  file.write(' ' + os.linesep)
  file.write('CHL' + os.linesep)
  file.write(txtchl2 + os.linesep)
  file.write(' ' + os.linesep)
file.close()

with open("./plots/NUTstat_expt022_orig.txt",'w') as file:
  file.write('expt022' + os.linesep)
  file.write(' ' + os.linesep)
  file.write('NO3' + os.linesep)
  file.write(txtno33 + os.linesep)
  file.write(' ' + os.linesep)
  file.write('SIL' + os.linesep)
  file.write(txtsil3 + os.linesep)
  file.write(' ' + os.linesep)
  file.write('PHO' + os.linesep)
  file.write(txtpho3 + os.linesep)
  file.write(' ' + os.linesep)
  file.write('CHL' + os.linesep)
  file.write(txtchl3 + os.linesep)
  file.write(' ' + os.linesep)
file.close()

### NUTRIENTS WITH WOA ###################################### 

ncf = '/cluster/projects/nn2993k/ModelInput/WOA2013/Nutrients/netcdfs/woa13_all_n00_01.nc'
nc = NetCDFFile(ncf)
WOAno3 = nc.variables['n_an'][0,0,:,:]
WOAno3100 = nc.variables['n_an'][0,20,:,:]
latw = nc.variables['lat'][:]
lonw = nc.variables['lon'][:]
nc.close()
ncf = '/cluster/projects/nn2993k/ModelInput/WOA2013/Nutrients/netcdfs/woa13_all_p00_01.nc'
nc = NetCDFFile(ncf)
WOApo4 = nc.variables['p_an'][0,0,:,:]
WOApho100 = nc.variables['p_an'][0,20,:,:]
nc.close()
ncf = '/cluster/projects/nn2993k/ModelInput/WOA2013/Nutrients/netcdfs/woa13_all_i00_01.nc'
nc = NetCDFFile(ncf)
WOAsi = nc.variables['i_an'][0,0,:,:]
WOAsi100 = nc.variables['i_an'][0,20,:,:]
nc.close()

xw1,yw1=np.meshgrid(lonw,latw)
xw,yw=m(xw1,yw1)



cmin = 0.; cmax = 15.
var=Interpolated2['NO3']["annual"][0,:,:]
var = numpy.ma.masked_where(depthm<5.,var)
title = 'Model Nitrate (5m)' 
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r')
figure=plt.figure(figsize=(12,7))

ax=figure.add_subplot(3,4,1)
levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(x,y,numpy.rot90(var),cmap=cmap,norm=norm)
plt.title(title,FontSize=15)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
plt.text(-0.25,0.85, 'a)',transform=ax.transAxes,FontSize=20)

ax=figure.add_subplot(3,4,2)
pmesh = m.pcolormesh(xw,yw,WOAno3,cmap=cmap,norm=norm)
title = 'WOA Nitrate (5m)'
plt.title(title,FontSize=15)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')

var=Interpolated2['NO3']["annual"][3,:,:]
var = numpy.ma.masked_where(depthm<100.,var)

ax=figure.add_subplot(3,4,3)
pmesh = m.pcolormesh(x,y,numpy.rot90(var),cmap=cmap,norm=norm)
title = 'Model Nitrate (100m)'      
plt.title(title,FontSize=15)


m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')

ax=figure.add_subplot(3,4,4)
pmesh = m.pcolormesh(xw,yw,WOAno3100,cmap=cmap,norm=norm)
title = 'WOA Nitrate (100m)'
plt.title(title,FontSize=15)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
#cbaxes = figure.add_axes([0.3, 0.0257, 0.015, 0.175])
#cb = ax.figure.colorbar(pmesh, cax = cbaxes)

plt.colorbar()




cmin = 0.; cmax = 1.5
var=Interpolated2['PHO']["annual"][0,:,:]
var = numpy.ma.masked_where(depthm<5.,var)
title = 'Model Phosphate (5m)' 

ax=figure.add_subplot(3,4,5)
levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(x,y,numpy.rot90(var),cmap=cmap,norm=norm)
plt.title(title,FontSize=15)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
plt.text(-0.25,0.85, 'b)',transform=ax.transAxes,FontSize=20)

ax=figure.add_subplot(3,4,6)
pmesh = m.pcolormesh(xw,yw,WOApo4,cmap=cmap,norm=norm)
title = 'WOA Phosphate (5m)'
plt.title(title,FontSize=15)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')

var=Interpolated2['PHO']["annual"][3,:,:]
var = numpy.ma.masked_where(depthm<100.,var)

ax=figure.add_subplot(3,4,7)
pmesh = m.pcolormesh(x,y,numpy.rot90(var),cmap=cmap,norm=norm)
title = 'Model Phosphate (100m)'      
plt.title(title,FontSize=15)


m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')

ax=figure.add_subplot(3,4,8)
pmesh = m.pcolormesh(xw,yw,WOApho100,cmap=cmap,norm=norm)
title = 'WOA Phosphate (100m)'
plt.title(title,FontSize=15)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')

plt.colorbar()


cmin = 0.; cmax = 30.
var=Interpolated2['SIL']["annual"][0,:,:]
var = numpy.ma.masked_where(depthm<5.,var)
title = 'Model Silicate (5m)' 
warnings.filterwarnings('ignore')
cmap = plt.get_cmap('Spectral_r')

ax=figure.add_subplot(3,4,9)
levels = MaxNLocator(nbins=15).tick_values(cmin, cmax)
norm = BoundaryNorm(levels, ncolors=cmap.N, clip=True)
pmesh = m.pcolormesh(x,y,numpy.rot90(var),cmap=cmap,norm=norm)
plt.title(title,FontSize=15)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
plt.text(-0.25,0.85, 'c)',transform=ax.transAxes,FontSize=20)

ax=figure.add_subplot(3,4,10)
pmesh = m.pcolormesh(xw,yw,WOAsi,cmap=cmap,norm=norm)
title = 'WOA Silicate (5m)'
plt.title(title,FontSize=15)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')

var=Interpolated2['SIL']["annual"][3,:,:]
var = numpy.ma.masked_where(depthm<100.,var)

ax=figure.add_subplot(3,4,11)
pmesh = m.pcolormesh(x,y,numpy.rot90(var),cmap=cmap,norm=norm)
title = 'Model Silicate (100m)'      
plt.title(title,FontSize=15)


m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')

ax=figure.add_subplot(3,4,12)
pmesh = m.pcolormesh(xw,yw,WOAsi100,cmap=cmap,norm=norm)
title = 'WOA Silicate (100m)'
plt.title(title,FontSize=15)

m.drawcoastlines(linewidth=0.25)
m.fillcontinents(color='lightgrey')
m.drawparallels(numpy.arange(-80.,81.,20.))
m.drawmeridians(numpy.arange(-180.,181.,20.))
m.drawmapboundary(fill_color='whitesmoke')
#cbaxes = figure.add_axes([0.3, 0.0257, 0.015, 0.175])
#cb = ax.figure.colorbar(pmesh, cax = cbaxes)

plt.colorbar()


plt.tight_layout()

figure.canvas.print_figure('./plots/nutrients_with_woa.png')

